@@ -12,7 +12,6 @@ python -m arcade.examples.asteroids
 import pyglet
 import arcade
 import os
-import math
 from typing import cast, Dict, Tuple, List, Any
 from enum import Enum
 
@@ -88,7 +87,6 @@ class AsteroidGame(arcade.Window):
 
         # Set up the game instance
         self.game_over = None
-        self.controller_name = None
 
         # Evaluation analytics
         self.score = None
@@ -161,6 +159,8 @@ class AsteroidGame(arcade.Window):
             self.set_size(self.scenario.game_map.width, self.scenario.game_map.height)
 
         self._print_terminal("**********************************************************")
+        if hasattr(self, 'controller'):
+            self._print_terminal(f"Controller: {self.controller.name if hasattr(self, 'controller') else ''}")
         self._print_terminal(f"Scenario: {self.scenario.name}")
         self._print_terminal(f"- - - - - - - - - - - - - - - - - - - - - - - - - - - - -")
 
